<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "New York";
    var qsoPartyUrl = "http://www.rdxa.com/index.php/";
    var overlayUrl = "http://www.no5w.com/OverlayNewYorkRev4.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Albany", "alb");
  countySelection.options[1] = new Option("Allegany", "all");
  countySelection.options[2] = new Option("Bronx", "brx");
  countySelection.options[3] = new Option("Broome", "brm");
  countySelection.options[4] = new Option("Cattaraugus", "cat");
  countySelection.options[5] = new Option("Cayuga", "cay");
  countySelection.options[6] = new Option("Chautauqua", "cha");
  countySelection.options[7] = new Option("Chemung", "che");
  countySelection.options[8] = new Option("Chenango", "cgo");
  countySelection.options[9] = new Option("Clinton", "cli");
  countySelection.options[10] = new Option("Columbia", "col");
  countySelection.options[11] = new Option("Cortland", "cor");
  countySelection.options[12] = new Option("Delaware", "del");
  countySelection.options[13] = new Option("Dutchess", "dut");
  countySelection.options[14] = new Option("Erie", "eri");
  countySelection.options[15] = new Option("Essex", "ess");
  countySelection.options[16] = new Option("Franklin", "fra");
  countySelection.options[17] = new Option("Fulton", "ful");
  countySelection.options[18] = new Option("Genesee", "gen");
  countySelection.options[19] = new Option("Greene", "gre");
  countySelection.options[20] = new Option("Hamilton", "ham");
  countySelection.options[21] = new Option("Herkimer", "her");
  countySelection.options[22] = new Option("Jefferson", "jef");
  countySelection.options[23] = new Option("Kings", "kin");
  countySelection.options[24] = new Option("Lewis", "lew");
  countySelection.options[25] = new Option("Livingston", "liv");
  countySelection.options[26] = new Option("Madison", "mad");
  countySelection.options[27] = new Option("Monroe", "mon");
  countySelection.options[28] = new Option("Montgomery", "mtg");
  countySelection.options[29] = new Option("Nassau", "nas");
  countySelection.options[30] = new Option("NewYork", "new");
  countySelection.options[31] = new Option("Niagara", "nia");
  countySelection.options[32] = new Option("Oneida", "one");
  countySelection.options[33] = new Option("Onondaga", "ono");
  countySelection.options[34] = new Option("Ontario", "ont");
  countySelection.options[35] = new Option("Orange", "ora");
  countySelection.options[36] = new Option("Orleans", "orl");
  countySelection.options[37] = new Option("Oswego", "osw");
  countySelection.options[38] = new Option("Otsego", "ots");
  countySelection.options[39] = new Option("Putnam", "put");
  countySelection.options[40] = new Option("Queens", "que");
  countySelection.options[41] = new Option("Rensselaer", "ren");
  countySelection.options[42] = new Option("Richmond", "ric");
  countySelection.options[43] = new Option("Rockland", "roc");
  countySelection.options[44] = new Option("Saratoga", "sar");
  countySelection.options[45] = new Option("Schenectady", "sch");
  countySelection.options[46] = new Option("Schoharie", "sco");
  countySelection.options[47] = new Option("Schuyler", "scu");
  countySelection.options[48] = new Option("Seneca", "sen");
  countySelection.options[49] = new Option("St.Lawrence", "stl");
  countySelection.options[50] = new Option("Steuben", "ste");
  countySelection.options[51] = new Option("Suffolk", "suf");
  countySelection.options[52] = new Option("Sullivan", "sul");
  countySelection.options[53] = new Option("Tioga", "tio");
  countySelection.options[54] = new Option("Tompkins", "tom");
  countySelection.options[55] = new Option("Ulster", "uls");
  countySelection.options[56] = new Option("Warren", "war");
  countySelection.options[57] = new Option("Washington", "was");
  countySelection.options[58] = new Option("Wayne", "way");
  countySelection.options[59] = new Option("Westchester", "wes");
  countySelection.options[60] = new Option("Wyoming", "wyo");
  countySelection.options[61] = new Option("Yates", "yat");
  addMarker(42.61490000, -73.97080000, "Albany", "alb");
  addMarker(42.26000000, -78.01620000, "Allegany", "all");
  addMarker(40.85170000, -73.84100000, "Bronx", "brx");
  addMarker(42.20670000, -75.74490000, "Broome", "brm");
  addMarker(42.27040000, -78.68470000, "Cattaraugus", "cat");
  addMarker(43.16330000, -76.50960000, "Cayuga", "cay");
  addMarker(42.34250000, -79.41090000, "Chautauqua", "cha");
  addMarker(42.14730000, -76.75090000, "Chemung", "che");
  addMarker(42.47020000, -75.59130000, "Chenango", "cgo");
  addMarker(44.72020000, -73.68020000, "Clinton", "cli");
  addMarker(42.24400000, -73.64110000, "Columbia", "col");
  addMarker(42.59930000, -76.06940000, "Cortland", "cor");
  addMarker(42.18310000, -74.92560000, "Delaware", "del");
  addMarker(41.75990000, -73.74370000, "Dutchess", "dut");
  addMarker(42.76830000, -78.88710000, "Erie", "eri");
  addMarker(44.14570000, -73.81530000, "Essex", "ess");
  addMarker(44.55270000, -74.31790000, "Franklin", "fra");
  addMarker(43.13590000, -74.43580000, "Fulton", "ful");
  addMarker(42.99820000, -78.18480000, "Genesee", "gen");
  addMarker(42.28040000, -74.15550000, "Greene", "gre");
  addMarker(43.66760000, -74.45700000, "Hamilton", "ham");
  addMarker(43.46100000, -74.95750000, "Herkimer", "her");
  addMarker(44.03570000, -76.09040000, "Jefferson", "jef");
  addMarker(40.64520000, -73.94500000, "Kings", "kin");
  addMarker(43.81870000, -75.48040000, "Lewis", "lew");
  addMarker(42.72990000, -77.77390000, "Livingston", "liv");
  addMarker(42.95430000, -75.61660000, "Madison", "mad");
  addMarker(43.28600000, -77.68430000, "Monroe", "mon");
  addMarker(42.91020000, -74.42350000, "Montgomery", "mtg");
  addMarker(40.75470000, -73.60170000, "Nassau", "nas");
  addMarker(40.78090000, -73.97720000, "NewYork", "new");
  addMarker(43.32680000, -78.83060000, "Niagara", "nia");
  addMarker(43.23930000, -75.47800000, "Oneida", "one");
  addMarker(43.02140000, -76.19770000, "Onondaga", "ono");
  addMarker(42.80820000, -77.28750000, "Ontario", "ont");
  addMarker(41.38780000, -74.35500000, "Orange", "ora");
  addMarker(43.38100000, -78.23130000, "Orleans", "orl");
  addMarker(43.43130000, -76.20050000, "Oswego", "osw");
  addMarker(42.61130000, -75.02340000, "Otsego", "ots");
  addMarker(41.42440000, -73.75630000, "Putnam", "put");
  addMarker(40.65100000, -73.87120000, "Queens", "que");
  addMarker(42.71140000, -73.52560000, "Rensselaer", "ren");
  addMarker(40.56460000, -74.14690000, "Richmond", "ric");
  addMarker(41.16090000, -74.06080000, "Rockland", "roc");
  addMarker(43.08680000, -73.86670000, "Saratoga", "sar");
  addMarker(42.83330000, -74.05800000, "Schenectady", "sch");
  addMarker(42.59230000, -74.43810000, "Schoharie", "sco");
  addMarker(42.39030000, -76.86320000, "Schuyler", "scu");
  addMarker(42.78280000, -76.78370000, "Seneca", "sen");
  addMarker(44.53310000, -75.19290000, "St.Lawrence", "stl");
  addMarker(42.28950000, -77.35750000, "Steuben", "ste");
  addMarker(40.92230000, -72.63740000, "Suffolk", "suf");
  addMarker(41.71900000, -74.75570000, "Sullivan", "sul");
  addMarker(42.20440000, -76.32210000, "Tioga", "tio");
  addMarker(42.44520000, -76.46720000, "Tompkins", "tom");
  addMarker(41.87880000, -74.34570000, "Ulster", "uls");
  addMarker(43.51290000, -73.82570000, "Warren", "war");
  addMarker(43.37490000, -73.43910000, "Washington", "was");
  addMarker(43.34840000, -77.04520000, "Wayne", "way");
  addMarker(41.11910000, -73.73300000, "Westchester", "wes");
  addMarker(42.69470000, -78.22150000, "Wyoming", "wyo");
  addMarker(42.61180000, -77.12840000, "Yates", "yat");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

